==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/ZleceniePrzedmiot.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class ZleceniePrzedmiot extends GenericDPSObject {
    /**
     * ZLECENIE_PRZEDMIOT.ZLECENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zlecenieId;

    /**
     * ZLECENIE_PRZEDMIOT.INFO_DOBOR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String infoDobor;

    /**
     * ZLECENIE_PRZEDMIOT.KOD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String kod;

    /**
     * ZLECENIE_PRZEDMIOT.LICZBA_SZTUK
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer liczbaSztuk;

    /**
     * ZLECENIE_PRZEDMIOT.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwa;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZLECENIE_PRZEDMIOT.ZLECENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZlecenieId() {
        return zlecenieId;
    }

    /**
     * ZLECENIE_PRZEDMIOT.ZLECENIE_ID
     *
     * @param zlecenieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZlecenieId(Long zlecenieId) {
        this.zlecenieId = zlecenieId;
    }

    /**
     * @return ZLECENIE_PRZEDMIOT.INFO_DOBOR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getInfoDobor() {
        return infoDobor;
    }

    /**
     * ZLECENIE_PRZEDMIOT.INFO_DOBOR
     *
     * @param infoDobor
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInfoDobor(String infoDobor) {
        this.infoDobor = infoDobor == null ? null : infoDobor.trim();
    }

    /**
     * @return ZLECENIE_PRZEDMIOT.KOD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getKod() {
        return kod;
    }

    /**
     * ZLECENIE_PRZEDMIOT.KOD
     *
     * @param kod
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKod(String kod) {
        this.kod = kod == null ? null : kod.trim();
    }

    /**
     * @return ZLECENIE_PRZEDMIOT.LICZBA_SZTUK
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getLiczbaSztuk() {
        return liczbaSztuk;
    }

    /**
     * ZLECENIE_PRZEDMIOT.LICZBA_SZTUK
     *
     * @param liczbaSztuk
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setLiczbaSztuk(Integer liczbaSztuk) {
        this.liczbaSztuk = liczbaSztuk;
    }

    /**
     * @return ZLECENIE_PRZEDMIOT.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * ZLECENIE_PRZEDMIOT.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZleceniePrzedmiot other = (ZleceniePrzedmiot) that;
        return (this.getZlecenieId() == null ? other.getZlecenieId() == null : this.getZlecenieId().equals(other.getZlecenieId()))
            && (this.getInfoDobor() == null ? other.getInfoDobor() == null : this.getInfoDobor().equals(other.getInfoDobor()))
            && (this.getKod() == null ? other.getKod() == null : this.getKod().equals(other.getKod()))
            && (this.getLiczbaSztuk() == null ? other.getLiczbaSztuk() == null : this.getLiczbaSztuk().equals(other.getLiczbaSztuk()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getZlecenieId() == null) ? 0 : getZlecenieId().hashCode());
        result = prime * result + ((getInfoDobor() == null) ? 0 : getInfoDobor().hashCode());
        result = prime * result + ((getKod() == null) ? 0 : getKod().hashCode());
        result = prime * result + ((getLiczbaSztuk() == null) ? 0 : getLiczbaSztuk().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", zlecenieId=").append(zlecenieId);
        sb.append(", infoDobor=").append(infoDobor);
        sb.append(", kod=").append(kod);
        sb.append(", liczbaSztuk=").append(liczbaSztuk);
        sb.append(", nazwa=").append(nazwa);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/ZleceniePrzedmiot.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class ZleceniePrzedmiot extends GenericDPSObject {
    /**
     * ZLECENIE_PRZEDMIOT.ZLECENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zlecenieId;

    /**
     * ZLECENIE_PRZEDMIOT.INFO_DOBOR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String infoDobor;

    /**
     * ZLECENIE_PRZEDMIOT.KOD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String kod;

    /**
     * ZLECENIE_PRZEDMIOT.LICZBA_SZTUK
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer liczbaSztuk;

    /**
     * ZLECENIE_PRZEDMIOT.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwa;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZLECENIE_PRZEDMIOT.ZLECENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZlecenieId() {
        return zlecenieId;
    }

    /**
     * ZLECENIE_PRZEDMIOT.ZLECENIE_ID
     *
     * @param zlecenieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZlecenieId(Long zlecenieId) {
        this.zlecenieId = zlecenieId;
    }

    /**
     * @return ZLECENIE_PRZEDMIOT.INFO_DOBOR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getInfoDobor() {
        return infoDobor;
    }

    /**
     * ZLECENIE_PRZEDMIOT.INFO_DOBOR
     *
     * @param infoDobor
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInfoDobor(String infoDobor) {
        this.infoDobor = infoDobor == null ? null : infoDobor.trim();
    }

    /**
     * @return ZLECENIE_PRZEDMIOT.KOD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getKod() {
        return kod;
    }

    /**
     * ZLECENIE_PRZEDMIOT.KOD
     *
     * @param kod
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKod(String kod) {
        this.kod = kod == null ? null : kod.trim();
    }

    /**
     * @return ZLECENIE_PRZEDMIOT.LICZBA_SZTUK
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getLiczbaSztuk() {
        return liczbaSztuk;
    }

    /**
     * ZLECENIE_PRZEDMIOT.LICZBA_SZTUK
     *
     * @param liczbaSztuk
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setLiczbaSztuk(Integer liczbaSztuk) {
        this.liczbaSztuk = liczbaSztuk;
    }

    /**
     * @return ZLECENIE_PRZEDMIOT.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * ZLECENIE_PRZEDMIOT.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZleceniePrzedmiot other = (ZleceniePrzedmiot) that;
        return (this.getZlecenieId() == null ? other.getZlecenieId() == null : this.getZlecenieId().equals(other.getZlecenieId()))
            && (this.getInfoDobor() == null ? other.getInfoDobor() == null : this.getInfoDobor().equals(other.getInfoDobor()))
            && (this.getKod() == null ? other.getKod() == null : this.getKod().equals(other.getKod()))
            && (this.getLiczbaSztuk() == null ? other.getLiczbaSztuk() == null : this.getLiczbaSztuk().equals(other.getLiczbaSztuk()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getZlecenieId() == null) ? 0 : getZlecenieId().hashCode());
        result = prime * result + ((getInfoDobor() == null) ? 0 : getInfoDobor().hashCode());
        result = prime * result + ((getKod() == null) ? 0 : getKod().hashCode());
        result = prime * result + ((getLiczbaSztuk() == null) ? 0 : getLiczbaSztuk().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", zlecenieId=").append(zlecenieId);
        sb.append(", infoDobor=").append(infoDobor);
        sb.append(", kod=").append(kod);
        sb.append(", liczbaSztuk=").append(liczbaSztuk);
        sb.append(", nazwa=").append(nazwa);
        sb.append("]");
        return sb.toString();
    }
}
